amachine.am_pattern API documentation

# amachine.am_pattern

View Source

     1class Pattern :
     2
     3	def __init__(self) :
     4		pass
     5
     6class DfaPattern( Pattern ) :
     7
     8	"""
     9	Analysis of pattern overlaps and
    10	exact computation of P-values of pattern occurrences numbers:
    11	case of Hidden Markov Models." Régnier (2014)
    12	"""
    13
    14	"""
    15	Probabilistic Arithmetic Automata and
    16	their Applications∗, Marschall (2024)
    17	"""
    18
    19	def __init__(self) :
    20		pass

class Pattern: View Source

    3class Pattern :
    4
    5	def __init__(self) :
    6		pass

class DfaPattern(Pattern): View Source

     8class DfaPattern( Pattern ) :
     9
    10	"""
    11	Analysis of pattern overlaps and
    12	exact computation of P-values of pattern occurrences numbers:
    13	case of Hidden Markov Models." Régnier (2014)
    14	"""
    15
    16	"""
    17	Probabilistic Arithmetic Automata and
    18	their Applications∗, Marschall (2024)
    19	"""
    20
    21	def __init__(self) :
    22		pass

Analysis of pattern overlaps and exact computation of P-values of pattern occurrences numbers: case of Hidden Markov Models." Régnier (2014)